@@ -9,32 +9,36 @@ from pge.init.add import actual
 
 def powerlaw(n, alp, st=1, ac=0.3, status=None, status_back=False):
     if status is None:
-        alp_ = alp + 0.5
+        alp_ = alp
     else:
         alp_ = status
     while True:
-        rs = np.trunc(nx.utils.powerlaw_sequence(n, alp_)) - 1 + st
+        rs = np.trunc(nx.utils.powerlaw_sequence(n, alp_+1)) - 1 + st
         alp2 = boot_estimate(
             HillEstimator,
             rs,
-            1 / 2,
             2 / 3,
-            50,
-            speed=False
-        )[0]
-        if np.abs(alp2-alp) <= ac:
+            1 / 2,
+            50, spec=True
+        )
+
+        if ~alp2[1]:
+            continue
+        print(alp, alp2[0])
+
+        if np.abs(alp2[0][0]-alp) <= ac:
             break
         else:
-            if alp2 > alp:
-                alp_ -= 0.15
+            if alp2[0][0] > alp:
+                alp_ -= 0.1
             else:
-                alp_ += 0.15
+                alp_ += 0.4
     if status_back:
         return rs, alp_
     return rs
 
 
-def powerlaw_degree(n, alpha, beta, ac=0.3, status=(None, None), rep=10):
+def powerlaw_degree(n, alpha, beta, ac=0.3, status=(None, None), rep=5):
     out_d, out_status = powerlaw(n, beta, 1, ac=ac, status_back=True, status=status[0])
     ind_d, in_status = powerlaw(n, alpha, 1, ac=ac, status_back=True, status=status[1])
 
@@ -58,7 +62,7 @@ def powerlaw_degree(n, alpha, beta, ac=0.3, status=(None, None), rep=10):
 
 class Creator:
     @staticmethod
-    def tbt(nm, alpha, beta, prm=0.7):
+    def tbt(nm, alpha, beta, prm=0.3):
         k = 1 - min([0.5, 1 - alpha ** -1, 1 - beta ** -1]) / 2
         zv = nm
 
