@@ -1,7 +1,7 @@
 import networkx as nx
 
 
-def estimate_rank(graph, tp, pers="tel", c=0.85, max_iter=100, eps=0.000001, w=None):
+def estimate_rank(graph, tp, pers=None, c=0.85, max_iter=100, eps=0.000001, w=None):
     if pers is None:
         tel = {node: 1/graph.size() for node in graph.get_ids()}
     else:
